TRUE elements indicating rows in the data that are
linked.match_any_linker(from_data, to_data = from_data)data.frame-like object
containing the keys for linking the corresponding rows to
rows in to_datadata.frame-like object containing
the keys that will be matched against the keys in
from_datafrom_data rows
are linkedmatch_any_linker function links rows in
from_data to rows in to_data that share the
same key. By convention, a key is defined as the combination of the
values in every column of from_data and
to_data. Thus, from_data and to_data
should contain only the columns necessary for key
generation. They should not be an entire dataset.